==> 15.9.zip: optimizer/Optimizer/Constants.cs <==
﻿namespace Optimizer
{
    internal static class Constants
    {
        internal static string DOWNLOADS_FOLDER = "OptimizerDownloads";
        internal static string InternalDNS = "1.1.1.1";

        internal static string INDICIUM_TOOL = "indicium";
        internal static string UWP_TOOL = "uwp";
        internal static string APPS_TOOL = "apps";
        internal static string HOSTS_EDITOR = "hosts";
        internal static string STARTUP_TOOL = "startup";
        internal static string CLEANER_TOOL = "cleaner";
        internal static string INTEGRATOR_TOOL = "integrator";
        internal static string PINGER_TOOL = "pinger";

        internal static string ENGLISH = "English";
        internal static string RUSSIAN = "Русский";
        internal static string TURKISH = "Türkçe";
        internal static string HELLENIC = "Ελληνικά";
        internal static string GERMAN = "Deutsch";
        internal static string PORTUGUESE = "Português";
        internal static string FRENCH = "Français";
        internal static string SPANISH = "Español";
        internal static string ITALIAN = "Italiano";
        internal static string CHINESE = "简体中文";
        internal static string TAIWANESE = "繁體中文";
        internal static string CZECH = "Čeština";
        internal static string KOREAN = "한국어";
        internal static string POLISH = "Polski";
        internal static string ARABIC = "العربية";
        internal static string KURDISH = "کوردی";
        internal static string HUNGARIAN = "Magyar";
        internal static string ROMANIAN = "Română";
        internal static string DUTCH = "Nederlands";
        internal static string UKRAINIAN = "українська";
        internal static string JAPANESE = "日本語";
        internal static string PERSIAN = "فارسی";
        internal static string NEPALI = "नेपाली";

        internal static string CloudflareDNS = "Cloudflare";
        internal static string OpenDNS = "OpenDNS";
        internal static string Quad9DNS = "Quad9";
        internal static string GoogleDNS = "Google";
        internal static string AlternateDNS = "AlternateDNS";
        internal static string AdguardDNS = "Adguard";
        internal static string CleanBrowsingDNS = "CleanBrowsing";
        internal static string CleanBrowsingAdultFilterDNS = "CleanBrowsing (adult filter)";
        internal static string AutomaticDNS = "Automatic";
        internal static string CustomDNS = "Custom";
    }
}

==> 16.5.zip: optimizer/Optimizer/Constants.cs <==
﻿namespace Optimizer {
    internal static class Constants {
        internal static string INTERNAL_DNS = "1.1.1.1";
        internal static string THEME_FLAG = "themeable";
        internal static int CONTRAST_THRESHOLD = 149;

        internal static string INDICIUM_TOOL = "indicium";
        internal static string UWP_TOOL = "uwp";
        internal static string APPS_TOOL = "apps";
        internal static string HOSTS_EDITOR = "hosts";
        internal static string STARTUP_TOOL = "startup";
        internal static string CLEANER_TOOL = "cleaner";
        internal static string INTEGRATOR_TOOL = "integrator";
        internal static string PINGER_TOOL = "pinger";

        internal static string ENGLISH = "English";
        internal static string RUSSIAN = "Русский";
        internal static string TURKISH = "Türkçe";
        internal static string HELLENIC = "Ελληνικά";
        internal static string GERMAN = "Deutsch";
        internal static string PORTUGUESE = "Português";
        internal static string FRENCH = "Français";
        internal static string SPANISH = "Español";
        internal static string ITALIAN = "Italiano";
        internal static string CHINESE = "简体中文";
        internal static string TAIWANESE = "繁體中文";
        internal static string CZECH = "Čeština";
        internal static string KOREAN = "한국어";
        internal static string POLISH = "Polski";
        internal static string ARABIC = "العربية";
        internal static string KURDISH = "کوردی";
        internal static string HUNGARIAN = "Magyar";
        internal static string ROMANIAN = "Română";
        internal static string DUTCH = "Nederlands";
        internal static string UKRAINIAN = "українська";
        internal static string JAPANESE = "日本語";
        internal static string PERSIAN = "فارسی";
        internal static string NEPALI = "नेपाली";
        internal static string BULGARIAN = "български";
        internal static string VIETNAMESE = "Tiếng Việt";

        internal static string CloudflareDNS = "Cloudflare";
        internal static string OpenDNS = "OpenDNS";
        internal static string Quad9DNS = "Quad9";
        internal static string GoogleDNS = "Google";
        internal static string AlternateDNS = "AlternateDNS";
        internal static string AdguardDNS = "Adguard";
        internal static string CleanBrowsingDNS = "CleanBrowsing";
        internal static string CleanBrowsingAdultFilterDNS = "CleanBrowsing (adult filter)";
        internal static string AutomaticDNS = "Automatic";
        internal static string CustomDNS = "Custom";
    }
}
